@@ -26,6 +26,7 @@
 #' * Multiple strings insert multiple notes sequentially: `list("Hello world", "Foo bar")`
 #' * A named list inserts a list with the name as superscript: `list("a" = list("Hello World"))`
 #' * A named list with positions inserts markers as superscripts inside table cells: `list("a" = list(i = 0:1, j = 2, text = "Hello World"))`
+#' @param rownames Logical. If `TRUE`, rownames are included as the first column
 #' @param ... Additional arguments are ignored
 #' @return An object of class `tt` representing the table.
 #' 
@@ -55,11 +56,12 @@
 #' 
 #' @export
 tt <- function(x,
-               digits = getOption("tinytable_tt_digits", default = NULL),
-               caption = NULL,
-               notes = NULL,
-               width = getOption("tinytable_tt_width", default = NULL),
-               theme = getOption("tinytable_tt_theme", default = NULL),
+               digits = get_option("tinytable_tt_digits", default = NULL),
+               caption = get_option("tinytable_tt_caption", default = NULL),
+               notes = get_option("tinytable_tt_notes", default = NULL),
+               width = get_option("tinytable_tt_width", default = NULL),
+               theme = get_option("tinytable_tt_theme", default = NULL),
+               rownames = get_option("tinytable_tt_rownames", default = FALSE),
                ...) {
 
 
@@ -81,6 +83,14 @@ tt <- function(x,
     colnames(x) <- cn
   }
 
+  # factors should all be characters (for replace, etc.)
+  # it might be dangerous to leave non-numerics, but what about dates and other character-coercibles?
+  for (i in seq_along(x)) {
+    if (is.factor(x[[i]])) {
+       x[[i]] <- as.character(x[[i]])
+    }
+  }
+
   assert_numeric(width, lower = 0, null.ok = TRUE)
   if (!length(width) %in% c(0, 1, ncol(x))) {
       msg <- sprintf("The `width` argument must have length 1 or %s.", ncol(x))
@@ -90,6 +100,15 @@ tt <- function(x,
       width <- width / sum(width)
   }
 
+  # bind the row names if the user explicitly asks for it in global option. 
+  # Same name as tibble::rownames_to_column()
+  assert_flag(rownames)
+  if (isTRUE(rownames) && !is.null(row.names(x))) {
+    rn <- data.frame(format(row.names(x)))
+    rn <- stats::setNames(rn, "rowname")
+    x <- cbind(rn, x)
+  }
+
   # formatting options are limited here
   # after creating the table since the new lazy system
   tab <- x
